
#  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.
#
#  This file is part of the TerraLib - a Framework for building GIS enabled applications.
#
#  TerraLib is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published by
#  the Free Software Foundation, either version 3 of the License,
#  or (at your option) any later version.
#
#  TerraLib is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with TerraLib. See COPYING. If not, write to
#  TerraLib Team at <terralib-team@terralib.org>.
#
#
#  Description: Helpers for TerraLib CMake
#
#  Author: Matheus Cavassan Zaglia
#

macro(TERRALIB_ADD_MODULE)
    set(options QT)
    set(oneValueArgs TARGET)
    set(multiValueArgs DEPENDENCIES SOURCES INCLUDES DEFINITIONS)
    cmake_parse_arguments(MODULE "${options}"
                                 "${oneValueArgs}"
                                 "${multiValueArgs}"
                                   ${ARGN})
    
    if(MODULE_QT)
        set(CMAKE_AUTOMOC ON)
        set(CMAKE_AUTOUIC ON)
        set(CMAKE_INCLUDE_CURRENT_DIR ON)
    endif()

    add_library(${MODULE_TARGET} SHARED ${MODULE_SOURCES})

    target_link_libraries(${MODULE_TARGET}      PUBLIC ${MODULE_DEPENDENCIES}) 
    target_include_directories(${MODULE_TARGET} PRIVATE ${MODULE_INCLUDES})
    target_compile_definitions(${MODULE_TARGET} PRIVATE ${MODULE_DEFINITIONS})
    target_compile_features(${MODULE_TARGET}    PUBLIC cxx_std_11)
    
    set_target_properties(${MODULE_TARGET} PROPERTIES 
                        VERSION ${PROJECT_VERSION_MAJOR}.${PROJECT_VERSION_MINOR}
                        SOVERSION ${PROJECT_VERSION_MAJOR}.${PROJECT_VERSION_MINOR}
                        )
    


    install(TARGETS ${MODULE_TARGET}
        EXPORT ${CMAKE_PROJECT_NAME}-targets
        RUNTIME DESTINATION ${TERRALIB_DESTINATION_RUNTIME} COMPONENT runtime
        LIBRARY DESTINATION ${TERRALIB_DESTINATION_LIBRARY} COMPONENT runtime
        ARCHIVE DESTINATION ${TERRALIB_DESTINATION_ARCHIVE} COMPONENT runtime)

    foreach(source ${MODULE_SOURCES})
        if("${source}" MATCHES ".*src\\/((terralib|terraview)\\/.*)(\\/.*\\.h)")
            install(FILES ${CMAKE_MATCH_0}
                    DESTINATION ${TERRALIB_DESTINATION_HEADERS}/${CMAKE_MATCH_1}
                    COMPONENT devel)
        endif() 
    endforeach()    
endmacro(TERRALIB_ADD_MODULE)
